@@ -1,4 +1,4 @@
-"verify.qmcc" <-
+`verify.qmcc` <-
 function(mydata, outcome = "", conditions = c(""), incl.rem = FALSE,
          expl.1 = FALSE, expl.0 = FALSE, expl.ctr = FALSE, expl.mo = FALSE,
          incl.1 = FALSE, incl.0 = FALSE, incl.ctr = FALSE, incl.mo = FALSE,
@@ -77,7 +77,7 @@ function(mydata, outcome = "", conditions = c(""), incl.rem = FALSE,
 }
 
          
-"verify.tt" <-
+`verify.tt` <-
 function(mydata, outcome = "", conditions = c(""), complete = FALSE, show.cases = FALSE) {
     
     if (nchar(outcome) == 0) {
